@@ -1,4 +1,4 @@
-;;; weather.el --- Weather Report -*- coding: iso-2022-3-compatible -*- 
+;;; weather.el --- Weather Report -*- coding: iso-2022-3-compatible -*-
 
 ;; Copyright (C) 1999-2001 Kenichi OKADA <okada@opaopa.org>
 
@@ -52,7 +52,7 @@
   (defun-maybe Meadow-version ()))
 
 (product-provide 'weather-version
-  (product-define "Weather" nil '(0 26)))
+  (product-define "Weather" nil '(0 27)))
 
 (defvar weather-insert-user-agent nil)
 
@@ -128,7 +128,7 @@
   (let ((repl weather-replace-alist))
     (while repl
       (setq text (weather-replace-in-string text
-					    (car (car repl)) 
+					    (car (car repl))
 					    (cdr (car repl))))
       (setq repl (cdr repl)))
     text))
@@ -244,12 +244,12 @@
 	    (unwind-protect
 		(setq connection
 		      (as-binary-process
-		       (open-network-stream "*Weather from http*" 
+		       (open-network-stream "*Weather from http*"
 					    buf
 					    (weather-server)
 					    (weather-port))))
 	      (if (null connection)
-		  (progn 
+		  (progn
 		    (if buf (kill-buffer buf))
 		    (weather-sleep)
 		    (throw 'done nil))))
@@ -326,7 +326,9 @@ If OFFLINE is nil, don't fetch weather, only use cache. "
 	     (null offline)
 	     (null (weather-sleep-p)))
 	(weather-sleep "Cannot get valid information."))
-    ret-val))
+    (if (interactive-p)
+	(message ret-val)
+      ret-val)))
 
 (defun weather-from-http-subr (where &optional offline)
   (let ((where (or where weather-where))
@@ -342,9 +344,7 @@ If OFFLINE is nil, don't fetch weather, only use cache. "
 	  (or (null weather-replace)
 	      (setq ret-val (weather-replace ret-val))
 	      (error "Weather: fail replace char."))
-	  (if (interactive-p)
-	      (message (weather-compose where ret-val))
-	    (weather-compose where ret-val))))))
+	  (weather-compose where ret-val)))))
 
 (defun weather-from-http-list (where-list &optional offline)
   (catch 'done
@@ -429,11 +429,11 @@ Otherwise treat \\ in NEWTEXT string as special:
     (narrow-to-region
      (goto-char (point-min))
      (goto-char (if (re-search-forward
-                     (format "^$\\|^%s$"
-                             (regexp-quote mail-header-separator))
-                     nil t)
-                    (match-beginning 0)
-                  (point-max))))))
+		     (format "^$\\|^%s$"
+			     (regexp-quote mail-header-separator))
+		     nil t)
+		    (match-beginning 0)
+		  (point-max))))))
 
 (defun weather-replace-header (&optional where offline)
   (interactive (list (read-from-minibuffer "Where: "
@@ -443,17 +443,20 @@ Otherwise treat \\ in NEWTEXT string as special:
 	       weather-message-where))
 	 (weather (weather-from-http where offline)))
     (if weather
- 	(save-excursion
- 	  (save-restriction
- 	    (weather-narrow-to-header)
+	(save-excursion
+	  (save-restriction
+	    (weather-narrow-to-header)
 	    (goto-char (point-min))
 	    (while (re-search-forward "^X-Weather:.*$" nil t)
 	      (delete-region (1- (match-beginning 0)) (match-end 0)))
- 	    (goto-char (point-max))
- 	    (insert "X-Weather: " weather "\n"))))))
+	    (goto-char (point-max))
+	    (insert "X-Weather: " weather "\n"))))))
 
 (defun weather-insert-header (&optional where offline)
-  (interactive)
+  (interactive (if (or current-prefix-arg
+		       (null weather-where))
+		   (list (read-from-minibuffer "Where: "
+					       weather-where))))
   (let ((weather (weather-from-http where offline)))
     (if weather
 	(save-excursion
@@ -526,12 +529,12 @@ Otherwise treat \\ in NEWTEXT string as special:
   "Print Weather version."
   (interactive)
   (let ((product-info
-         (concat (product-string-1 "Weather" t) 
+	 (concat (product-string-1 "Weather" t)
 		 " " weather-environment-version)))
     (if (interactive-p)
-        (message "%s" product-info)
+	(message "%s" product-info)
       product-info)))
 
 (provide 'weather)
 
-;;; weather.el ends here
+;;; weather.el ends here
\ No newline at end of file
